
OPTIONS ls=132 ps=199;

%LET pth = u:\sas\logistic\plots; * path of folder to place graphs;


proc format ;
value rsp  1='Very Good' 2='Good' 3='OK' 4='Bad' 5='Very Bad';
value rspA 1='a Very Good' 2='b Good' 3='c OK' 4='d Bad' 5='e Very Bad';
RUN;

data icecream;
input count brand $ tstN taste $;
brnd1 = (brand='ice1');
brnd2 = (brand='ice2');
datalines;
 70 ice1  1 vg
 71 ice1  2  g
151 ice1  3  m
 30 ice1  4  b
 46 ice1  5 vb
 20 ice2  1 vg
 36 ice2  2  g
130 ice2  3  m
 74 ice2  4  b
 70 ice2  5 vb
 50 ice3  1 vg
 55 ice3  2  g
140 ice3  3  m
 52 ice3  4  b
 50 ice3  5 vb
;

proc tabulate data=icecream noseps;
freq count;
class brand tstN / order=data;
table brand all, (tstN='Taste' all)*n=' '*f=6.0       / rts=12 box='Counts';
table brand all, (tstN='Taste'    )*rowpctn='Row %'*f=6.2 / rts=12 box='Percents';
format tstN rsp. ;
run;

* file with individual observations for each response;

DATA icecreamN;
SET icecream;
drop i count;
do i = 1 to count;
  output;
end;
proc CONTENTS DATA=icecreamN; run;

options mergenoby=warn;   * macros merge files without a BY statement;

* newer version of EmpiricalLogitPlot;

%INCLUDE 'u:\sas\_macros\emplogits.sas';

%EmpiricalLogitPlot(data=icecreamN,
                       y=tstN,            /* file with individual observations */
                       x=brand,           /* can enter character values */
                   const=0.5,
                 options=ascending PANEL  /* ascending matches the ascending option (default) in LOGISTIC,
                                             otherwise enter descending opposite direction */ 
                      ) / minoperator; 

* older version;

%INCLUDE 'u:\sas\_macros\ordinal_macros.sas';  * older version defines the same macro names as the newer version;

%EmpiricalLogitPlot(class= brnd1 brnd2, /* dummy coded classification factor */
                     cont= ,            /* continuous explanatory variable names */
                     data= icecreamN,   /* data set individual observations (not weighted by count */
                        y= tstN,        /* ordinal response variable, coded 1,2,3 .. */
                     numy= 5            /* number of response levels*/ );

%EXPlot(brnd1 brnd2,       /* list explanatory factors (all numeric with dummy codes for class variables)*/
        data= icecreamN,   /* data set individual observations (not weighted by count */
           y= tstN,        /* ordinal response variable, coded 1,2,3 .. */
        numy= 5            /* number of response levels*/  );

* LRT to evaluate if unequal slopes improve fit ;

%LRTest(data=icecreamN,
        class=brand / param=ref,
        model1= tstN = brand / ,
        model2= tstN = brand / unequalslopes);


* cumulative logit model;

ods select fitstatistics responseprofile oddsratiospl cumulativemodeltest;

proc LOGISTIC DATA=icecream ;
class brand / param=ref;
freq count;
model tstN = brand / link=clogit aggregate ; 
ODDSRATIO brand / cl=pl;
output out=prdC(keep=brand prdA _level_ ) predicted=prdA;  * alternate method to save predicted values;
title 'LOGISTIC: Cumulative Logit';
run;

* for more efficient way to process predicted values,
  follow the process outlined below with the SCORE statement for alogit predicted values;

proc print data=prdC; run;

proc sort data=prdc out=prdSc;
by brand _level_;
proc print; run;

data prdSc;
set prdSc;
by brand _level_;
if first._level_ then output;
drop tstN;
proc print; run;


proc transpose data=prdsc out=tprdSc(drop=_name_ _label_) prefix= _;
by brand; var prdA; id _level_;
proc print; run;

data tprdSd; set tprdSc;
p1 = _1;
p2 = _2 - _1;
p3 = _3 - _2;
p4 = _4 - _3;
p5 =  1 - _4;
sm = sum(p1, p2, p3, p4, p5);
drop _1 _2 _3 _4;

proc print data=tprdsd; id brand; run;

data probs;
set tprdSd;
keep brand taste prob;
ARRAY pp{5} p1 - p5;
DO taste = 1 to 5;
   prob = pp{taste};
   OUTPUT;
END;

proc print data=probs; run;

proc tabulate noseps data=probs;
CLASS brand taste;
VAR prob;
table brand, taste*prob=' '*sum=' '*f=6.3 / rts=9;
title 'Probabilities cumulative logit';
format taste rsp. ;
run;

* determine max and min probabilities for each brand;

proc means data=probs noprint;
by brand; VAR prob;
OUTPUT OUT=mnmx(keep = brand mn mx) min=mn max=mx;
proc print; run;


data plt; merge probs(keep=brand taste prob) mnmx;
by brand;
if first.brand = 0 then call missing(mn, mx);

proc sort; by brand taste; 

proc print data=plt label; id brand; run;


ods graphics on / reset = all height= 2 in width=6.5 in border= off ;
ods listing image_dpi=200 gpath="&pth";
ods graphics / imagename = "icecream_clogit" ;

PROC SGPlot DATA = plt noautolegend ;
STYLEATTRS datasymbols = (circlefilled trianglefilled squarefilled diamond circle)
            datacolors = (darkblue blue gray orange red )
    datacontrastcolors = (darkblue blue gray orange red )
      datalinepatterns = (solid dash mediumdash shortdash dot);
HIGHLOW y=brand low=mn high=mx / group=taste
                                 type=bar barwidth= .15 fill fillattrs=(color=cxc6dbef) nooutline ;
SCATTER y=brand x=prob  / group=taste name='rsp'
                          markerattrs=(size=6) 
                          datalabel=prob datalabelpos=top datalabelattrs=(color=black weight=bold size=3);
SERIES y = brand x = prob / group = taste lineattrs=(thickness=1) transparency=.6 ;
KEYLEGEND 'rsp' / noborder position =right across=1 down=3
                  title='Taste' titleattrs=(size=6 weight=bold)
                  valueattrs=(weight=bold size=5) sortorder=ascending;
yAXIS offsetmin=.15 offsetmax=.15 display=(noticks ) type=discrete
      label='Brand' labelattrs=(weight=bold size=7)
      VALUEATTRS=(weight=bold size=5) reverse;
xAXIS offsetmin=.03 offsetmax=.03 display=(nolabel)
      values=(0.05 to 0.45 by 0.05) VALUEATTRS=(weight=bold size=5);
TITLE "Logit: Response Probabilities";
FORMAT prob 5.2 taste rspA. ;
run;

ods graphics off;


* adjacent logit;

* enter factor names in a file to collect predicted values;

DATA iceScr;
brand = 'ice1'; output;
brand = 'ice2'; output;
brand = 'ice3'; output;
run;

proc print; run;

%dld(prds prdA mnmx pltA)

ods select fitstatistics responseprofile oddsratios;

proc LOGISTIC DATA=icecream ;
freq count;
class brand / param=ref;
model tstN = brand / link=alogit aggregate ; 
score data=iceScr out=prdA;
title 'LOGISTIC: Adjacent Logit';
run;

proc print data=prdA; run;

proc transpose data=prdA out=prds(drop=_label_) ;
by brand;
var P_1 P_2 P_3 P_4 P_5;

DATA prds;
SET prds;
DROP _name_;
rename col1=prdA;
taste = input(substr(_name_,3,1),1.0);
proc print; run;

proc tabulate noseps data=prds;
class brand taste;
var prdA;
table brand, taste*prdA=' '*sum=' '*f=6.3 / rts=16 box='Estimated Probabilities';
title 'predicted values alogit';
format taste rsp. ;
run;

proc means data=prds noprint;
by brand; VAR prdA;
OUTPUT OUT=mnmx(keep = brand mn mx) min=mn max=mx;
proc print; run;

data pltA; merge prds(keep=brand taste prdA) mnmx;
by brand;
if first.brand = 0 then call missing(mn, mx);

proc sort; by brand taste; 

proc print data=pltA label; id brand; run;

ods graphics on / reset = all height= 2 in width=6.5 in border= off ;
ods listing image_dpi=200 gpath="&pth";
ods graphics / imagename = "icecream_Alogit" ;

PROC SGPlot DATA = pltA noautolegend ;
STYLEATTRS datasymbols = (circlefilled trianglefilled squarefilled diamond circle)
            datacolors = (darkblue blue gray orange red )
           datacontrastcolors=(darkblue blue gray orange red )
           datalinepatterns=(solid dash mediumdash shortdash dot);
HIGHLOW y=brand low=mn high=mx / group=taste 
                                 type=bar barwidth= .15 fill fillattrs=(color=cxc6dbef) nooutline ;
SCATTER y=brand x=prdA  / group=taste name='mkr' markerattrs=(size=6)
                          datalabel=prdA datalabelpos=top datalabelattrs=(color=black weight=bold size=3);

SERIES y = brand x = prdA / group = taste lineattrs=(thickness=1) transparency=.6 ;
KEYLEGEND 'mkr' / noborder position =right across=1 down=3
                  title='Taste' titleattrs=(size=6 weight=bold)
                  valueattrs=(weight=bold size=5) sortorder=ascending;
yAXIS offsetmin=.15 offsetmax=.15 display=(noticks ) type=discrete
      label='Brand' labelattrs=(weight=bold size=7)
      VALUEATTRS=(weight=bold size=5) reverse
      /* splitchar="/" SPLITJUSTIFY=right FITPOLICY=SPLITALWAYS*/ ;
xAXIS offsetmin=.03 offsetmax=.03 display=(nolabel)
      values=(0.05 to .45 by .05) VALUEATTRS=(weight=bold size=5);
TITLE "Adjacent logit: Response Probabilities";
FORMAT prdA 5.2  taste rspA. ;
run;

ods graphics off;




* BACKACHE DATA: PROPORTIONAL ODDS MODEL;

/*
Problem Solving: A Statistician's Guide by Chris Chatfield
A popular text on Applied Statistics, now in its 2nd edition.

all women who gave birth in a London Hospital over a four-month period in 1973

backache data available in a downloadble text file at:

https://lib.stat.cmu.edu/datasets

data bckach;
input obs severity month age; * remainder of items unknown;
lnAge = Log(age);
if Severity = 0 then severity = 1;
trimester = (month > 6) + (Month > 3) + 1;  * divide 9 months into 3 equal time periods;
cards;
   1 1  0 26 1.52 54.5  75.0 3.35 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
   2 3  0 23 1.60 59.1  68.6 2.22 1 2 1 0 0 1 0 0 0 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0
   3 2  6 24 1.57 73.2  82.7 4.15 0 1 0 0 0 1 1 0 1 0 1 0 0 1 0 1 0 0 0 0 0 0 0 0 0
   4 1  8 22 1.52 41.4  47.3 2.81 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0
etc...
*/
options ls=132 ps=220;

%LET pth = u:\sas\logistic\plots;

proc format ;
value agC low - 25='15-25' 25<-33='25-33' 33<-high='33+';
Value sev 0,4=' '1='none or very little' 2='troublesome' 3='severe';
RUN;


%include 'u:\sas\logistic\backache.sas';


proc contents data=bckach; run;


proc tabulate data=bckach noseps;;
class age trimester severity;
table trimester*age, (severity all)*n*f=8.0 severity=' '*rowpctn='row %'*f=8.1 / rts=9 indent=1;
FORMAT age agC. severity sev. ;
run;



proc sort data=bckach;
by age trimester;
run;

proc freq data=bckach;
table trimester*severity / nocol nopercent;
run;

proc means data=bckach n min median mean max maxdec=2;
var age lnage;
run;


* jitter severity values to make graph;

data bckach;
set bckach;
sevP = severity - .3 + .6*ranuni(183);
run;

proc print data=bckach(obs=10) n; run;


proc PLOT data=bckach;
plot sevP*age =trimester / haxis = 15 to 45 by 5
                           vaxis =  0 to 4 by 1 vref=.5,1.5,2.5,3.5;
options ls=120 ps=45;
FORMAT sevP sev. ;
run; quit;

options ls=90 ps=200;

* newer macro;

%INCLUDE 'u:\sas\_macros\emplogits.sas';

%EmpiricalLogitPlot(data=bckach, y=severity, x=trimester lnage, const=0.5,
                    neighbors=50, smooth=.3, contcutoff=20 , options=ascending PANEL) / minoperator; 

* macros from 2013 SGF paper (uses same macro names as revised version);

%INCLUDE 'u:\sas\_macros\ordinal_macros.sas';

%EmpiricalLogitPlot(class= Trimester, /* classification factor */
                     cont= lnAge,     /* continuous */
                     data= Bckach,    /* data set*/
                        y= Severity,  /* ordinal response*/
                     numy= 3          /* number of response levels*/ );

%EXPlot(Trimester lnAge,  /* list factors (all numeric)*/
        data= Bckach,
           y= Severity,
        numy= 3);

%LRTest(data=bckach,
        class = trimester / param=ref,
        model1= severity = trimester lnage  ,
        model2= severity = trimester lnage / unequalslopes=trimester );



PROC DATASETS nolist;
DELETE odrtpl odrtpl2 bckachScr bprd1Scr prbs prbsA;
RUN; QUIT;

* scoring data set;

data bckachScr;
do trimester=  1, 2, 3;
  do age = 15 to 40 by 5; lnage=log(age); output;
  end;
end;

proc print; run;

ODS SELECT responseprofile parameterestimates ;*cumulativemodeltest;
ODS OUTPUT oddsratiospl=odrtpl;

proc logistic data=Bckach descending ; * notice descending option for response;
class Trimester / param=ref;
model Severity =lnAge Trimester / unequalslopes=Trimester;
oddsratio lnAge     / cl=pl;
oddsratio Trimester / cl=pl;
score data=bckachScr out=bprd1Scr(keep=trimester lnage age p_: ) ;
run;

proc print data=bprd1Scr; run;

PROC TRANSPOSE DATA=bprd1Scr OUT=prbs(drop=_label_);
by trimester age lnage;
var p_1 p_2 p_3;

data prbsA;
set prbs;
drop _name_;
rename col1 = pA;
severity = input(substr(_name_,3,1),1.0);
proc print; run;


proc sort data=prbsA; by severity trimester age ;

proc print data=prbsA; run;


* graph probabilities;

ods graphics on / reset = all height= 3 in width=6 in border= off ;
ods listing image_dpi=200 gpath="&pth";
ods graphics / imagename = "backache_sev" ;

proc sgpanel data=prbsA noautolegend;
STYLEATTRS datalinepatterns=(solid dash mediumdash )
           datacontrastcolors=(green blue red)
           datasymbols=(circlefilled squarefilled trianglefilled );
PANELBY trimester / onepanel rows=1 columns=3 headerattrs=(weight=bold size=8) ;
SERIES  x=age y=pA / group=severity lineattrs=(thickness=1) name="gr" ;*
                     curvelabel curvelabelpos=end curvelabelattrs=(color=black weight=bold size=4);
KEYLEGEND / noborder position=bottom across=3 down=1 title='Severity' titleattrs=(weight=bold size=6)
            valueattrs=(weight=bold size=4);
colAXIS offsetmin=.03 offsetmax=.05 values=(15 to 40 by 5) valueattrs=(color=black weight=bold size=6)
        label="Age" labelattrs=(color=black weight=bold size=7);
rowAXIS offsetmin=.04 offsetmax=.04 values=(0 to 0.9 by .10) grid
        valueattrs=(color=black weight=bold size=6)
        Label='Predicted Probability' labelattrs=(color=black weight=bold size=7);
TITLE 'Probability of Severity';
format severity sev. ;
run;

ODS graphics off;

ods graphics on / reset = all height= 3 in width=6 in border= off ;
ods listing image_dpi=200 gpath="&pth";
ods graphics / imagename = "backache_tri" ;

proc sgpanel data=prbsA noautolegend;
STYLEATTRS datalinepatterns=(solid dash mediumdash )
           datacontrastcolors=(green blue red)
           datasymbols=(circlefilled squarefilled trianglefilled );
PANELBY severity / onepanel rows=1 columns=3 headerattrs=(weight=bold size=8) ;
SERIES  x=age y=pA / group=trimester lineattrs=(thickness=1) name="gr" ;*
                     curvelabel curvelabelpos=end curvelabelattrs=(color=black weight=bold size=4);
KEYLEGEND / noborder position=bottom across=3 down=1 title='Trimester' titleattrs=(weight=bold size=6)
            valueattrs=(weight=bold size=4);
colAXIS offsetmin=.03 offsetmax=.05 values=(15 to 40 by 5) valueattrs=(color=black weight=bold size=6)
        label="Age" labelattrs=(color=black weight=bold size=7);
rowAXIS offsetmin=.04 offsetmax=.04 values=(0 to 0.9 by .10) grid valueattrs=(color=black weight=bold size=6)
        Label='Predicted Probability' labelattrs=(color=black weight=bold size=7);
TITLE 'Probability of Severity';
format severity sev. ;
run;

ODS graphics off;


* odds ratios for trimester;

proc print data=odrtpl noobs; run;

data odrtpl2;
set odrtpl;
if effect = 'lnAge' then delete;
IF LowerCL GT 1 or UpperCL LT 1 then
  do; oddsRatioEst2=oddsRatioEst; LowerCL2=LowerCL; UpperCL2=UpperCL;
     call missing(oddsRatioEst,LowerCL,UpperCL);
 END;

PROC PRINT; RUN;


ODS graphics on / reset = all width= 5 in  height=2.25 in border= off ;
ODS LISTING image_dpi=300 gpath="&pth" ;
ODS GRAPHICS / imagename = "backache_OR" ;

PROC SGPLOT DATA=odrtpl2 noautolegend;
REFLINE 1 / axis=x lineattrs=(pattern=21 thickness=1 color=blue) transparency=.6;
HIGHLOW y=effect low=lowercl  high=uppercl  / type=line lineattrs=(color=red   pattern=33 thickness=1) ;
HIGHLOW y=effect low=lowercl2 high=uppercl2 / type=line lineattrs=(color=black pattern=1 thickness=1) ;
SCATTER x=OddsRatioEst  y=effect / markerattrs=(color=red symbol= trianglefilled size=3)
                                   datalabel=oddsratioest datalabelattrs=(color=black size=4 weight=bold) datalabelpos=top;
SCATTER x=OddsRatioEst2 y=effect / markerattrs=(color=black symbol= circlefilled size=3)
                                   datalabel=oddsratioest2 datalabelattrs=(color=black size=4 weight=bold) datalabelpos=top;
REFLINE 0 / axis=x lineattrs=(pattern=1 thickness=1 color=black);
YAXIS offsetmin=0.1 offsetmax=0.1 type=discrete discreteorder=data display=(nolabel noticks)
      valueattrs=(weight=bold size=4) reverse
      splitchar=":" SPLITJUSTIFY=left FITPOLICY=splitalways;
xaxis offsetmin=.03 offsetmax=.05 values=(0 to 7.5 by 0.5) valueattrs=(size=7 weight=bold)
      label='Odds Ratio' labelattrs=(weight=bold size=9);
title 'Odds Ratios with Profile Likelihood 95% Confidence Limits';
format oddsratioest: 6.2;
RUN;

ods graphics off;


proc sort data=prbsA; by age severity trimester ;

PROC TABULATE DATA=prbsA noseps;
where age in (20, 30);
class age trimester severity; var pA;
table age, trimester, severity*pA=' '*sum=' '*f=9.5 / rts=11;
format severity sev. ;
title 'Odds Ratios from partial proportional odds model';
run;
