OPTIONS ls=110 ps=65;

%MACRO whitehead(dsn,A,k);

* for testing;
%*LET dsn = prbsC;
%*LET A = 1;  * ratio of group sample sizes;
%*LET k = 4;  * number of ordinal levels of the response;

proc means data=&dsn. noprint nway;
class rsp;  * average for each of the k levels of the response;
var p1;
output out=_pmns(drop=_type_ _freq_) mean=p;
*proc print; *title "response P for whitehead formula"; run;


DATA _Wpwr; SET _pmns end=eof;
p3 = p**3; smp3+p3;
DROP rsp p p3 num denm smp;
LABEL smp3 = "sum p^3 (avg p) across k levels";
if eof then 
do; smp = 1-smp3; call symputx("smp3", 1-smp3); power = 1 - &beta.;
    NUM = 3*((&A.+1)**2)*( probit(1- (&alpha./2)) + probit(1- &beta. ))**2;
    DENM= &A. * ( (LOG(&odrt.)**2) * smp );
    n_whitehead = ROUND( NUM/DENM ,1) ;
    output;
end;
run;

proc print data=_Wpwr noobs label; id power;
title "Whitehead Formula: alpha = &alpha, power = %sysevalf(1-&beta)";
run;

PROC DATASETS nolist;
DELETE _Wpwr _pmns _prbs;
RUN; QUIT;

%MEND;



* macro to initialize data set to store power calculations;

%MACRO _results;

DATA powerClgt;
call missing(alpha, nA, nB, nC, totalN, power_likelihood_ratio, power_score, OR_1, OR_2);
stop;
run;

%MEND;


* macro to compute power and append results to data set;

%macro ordpwr(dsn,gA,gB,gC);

%*LET dsn = prbsC; * input data;
%*LET gA=100;      * sample size for treatment groups;
%*LET gB=100;
%*LET gC=100;

DATA _cnts;
SET &dsn. ;
ARRAY cnt{3} _temporary_ (&gA. &gB. &gC.);
nn = ROUND(cnt{x}*p1,1);
RUN;
proc print; run;

PROC TABULATE DATA = _cnts noseps;
CLASS x rsp; freq nn;
table x='Treatment', (rsp='Response' all)*n*f=5.0 rsp=' '*rowpctn='row %'*f=5.1 / rts=12;
title "Exemplary Data: N1 = &gA | N2 = &gB | N3 = &gC";
run;

* save chi-square values from the Likelihood ratio and Score tests;

ods select responseprofile ;
ods output globaltests=_gbl3(where=(substr(test,1,2)='Li' or substr(test,1,2)='Sc' ))
           oddsratios= _odrtC;

proc LOGISTIC data = _cnts ;
freq nn;
class x(ref="&rf") / PARAM=ref;
model rsp = x / link=clogit PL;
title 'LOGISTIC: cumulative logit';
output out=prd(drop=rsp nn sm p) predicted=pred;
run;

proc print data=_odrtC; title "Odds Ratio"; run;

proc transpose data=_odrtC OUT=_odrtC(drop=_name_ _label_) prefix=OR_;
var oddsratioEst;
*proc print; run;

proc print data =_gbl3; title "Chisquare tests"; run;

* compute power for given sample size based on non-central chisquare ;

DATA _pwr; SET _gbl3;
alpha=&alpha. ;
nA = &gA. ;
nB = &gB. ;
nC = &gC. ;
totalN = SUM(nA, nB, nC);
c_crit = CINV(1-alpha,df);
powerC = 1-probchi(c_crit,df,ChiSq);
*proc print noobs; run;

proc transpose data=_pwr out=_powerC(drop=_name_ _label_) prefix = power_;
by alpha nA nB nC totalN;
var powerC;
id test;

data _powerC ; set _powerC ; set _odrtC;

proc print data=_powerC NOObs;
by alpha nA nB nC;
id totalN;
format power: 5.3;
title2 'LOGISTIC: power, sample size, odds ratios';
run;

proc append data=_powerC base=powerClgt force; run; quit;

PROC DATASETS nolist;
DELETE _cnts _powerC _pwr _gbl3 _pwr _odrtC;
RUN; QUIT;

%MEND;



* Whitehead example 1;

PROC DATASETS nolist;
DELETE cprbs root1 root1a prbsC;
RUN; QUIT;

* example 1 data: enter control level probabilities for the first 3 levels, the fourth by subtraction;

%LET odrt = 2.4286;  * odds ratio derived in article to match treatment probabilities;

data cprbs;
p21 = .2;
p22 = .5;
p23 = .2;
p24 = 1 - (p21 + p22 + p23); * control group probs;
odrt = &odrt. ;  * specify desired odds ratio [here, it is computed from P(Y LE 2) in the example] ;
run;

proc print; title 'Control probabilities'; run;

* skip to proc MODEL below;

* Example: Slide 16 from Part II of the presentation, results on Slide 17 (close to N=450);

%LET odrt = 1.75;    * enter desired odds ratio, can modify it to any value to recompute treatment probs;

data cprbs;
p21 = .3;
p22 = .4;
p23 = .2;
p24 = 1 - (p21 + p22 + p23); * control group probs;
odrt = &odrt. ;  * specify desired odds ratio [here, it is computed from P(Y LE 2) in the example] ;
run;

proc print; title 'Control probabilities'; run;


* four equations, four unknowns;

PROC MODEL DATA = cprbs;
(p11+ p12+ p13 +p14) - 1 = 0;
( ( 1/odrt ) * (p11            ) * ((p22 + p23 + p24) / (p21            ) )) - (p12 + p13 + p14) = 0;
( ( 1/odrt ) * (p11 + p12      ) * ((      p23 + p24) / (p21 + p22      ) )) - (      p13 + p14) = 0;
( ( 1/odrt ) * (p11 + p12 + p13) * ((            p24) / (p21 + p22 + p23) )) - (            p14) = 0;

solve p11 p12 p13 p14 / out=root1 ;
RUN; QUIT;
proc print NOobs; run;

proc transpose  data=root1 out=root1a name = probs prefix=p;
var p: ;
run;
proc print; run;

proc sort data=root1a; by probs;

proc print data=root1a; format p1 7.4; run;


data prbsC; set root1a;
  x = INPUT(substr(probs,2,1),2.0);
rsp = INPUT(substr(probs,3,1),2.0);
proc print data=prbsC; run;


%LET alpha = 0.05;   * type I error;
%LET beta  = .1;     * power = 1 - beta;

%whitehead(prbsC,1,4); * (data,A,k);
  * A = ratio of group sample sizes;
  * k = number of ordinal levels of the response;


%let rf = 2;   * category coded x=2 is reference (control) ;

%_results; * initialize data set to store results (needed for looping through a macro);


%ordpwr(prbsC,  94,  94, 0);* enter 0 for treatment level 3, not present here;
%ordpwr(prbsC, 100, 100, 0);

proc print data=powerclgt; id na nb nc; run;



* Whitehead Example 1;
* estimate odds ratio in PROC MODEL based on P(Y LE 2) entered for treatment x=1;


PROC DATASETS nolist;
DELETE cprbs2 root2 root2a prbsC;
RUN; QUIT;


data cprbs2;
p21 = .2; p22 = .5;  p23 = .2; p24 = 1 - (p21 + p22 + p23); * control group probs;
run;

proc print; run;


* solve for the four treatment probabilities AND the odds ratio;

* five equations, five unknowns: p11 p12 p13 p14 odrt;

PROC MODEL DATA = cprbs2;
(p11 + p12)             - 0.85 = 0;  * 0.85 is the increase due to treatment, PROB(Y LE 2); 
(p11 + p12 + p13 + p14) - 1    = 0;
( ( 1/odrt ) * (p11            ) * ( (p22 + p23 + p24) / (p21            ) ) ) - (p12 + p13 + p14) = 0;
( ( 1/odrt ) * (p11 + p12      ) * ( (      p23 + p24) / (p21 + p22      ) ) ) - (      p13 + p14) = 0;
( ( 1/odrt ) * (p11 + p12 + p13) * ( (            p24) / (p21 + p22 + p23) ) ) - (            p14) = 0;

solve p11 p12 p13 p14 odrt /out=root2 ;
RUN; QUIT;

proc transpose data=root2 out=root2a name = probs prefix=p;
var p: ;
run;

proc sort data=root2a; by probs;

data prbsC; set root2a;
  x = INPUT(substr(probs,2,1),2.0);
rsp = INPUT(substr(probs,3,1),2.0);
proc print; format p1 7.3; run;

%LET alpha = 0.05;
%let  k = 4;   * four level ordinal response variable;
%let rf = 2;   * category coded x=2 is reference (control) ;

%_results; * initialize data set to store results (needed for looping through a macro);

%ordpwr(prbsC,  50, 50, 0);  * enter 0 for treatment 3;
%ordpwr(prbsC,  75, 75, 0);
%ordpwr(prbsC,  94, 94, 0);
%ordpwr(prbsC, 110,110, 0);


proc print data=powerclgt;
BY alpha;
ID nA nB nC;
TITLE 'power, sample size, odds ratios (differ from target due to rounding group sample sizes to integers)';
FORMAT power: 7.3 or: 7.2;
run;


* Example: response has 3 ordinal categories;
*          three treatment categories coded 1,2,3 with 3 as the control or reference category;

* x=1: Treatment 1;
* x=2: Treatment 2;
* x=3: Control;

%LET odrtA = 3.0;  * treatment 1 vs 3 (control);
%LET odrtB = 2.0;  * treatment 2 vs 3 (control);

DATA cprbs3;
p31 = .20 ; p32 = .33; p33 = 1 - (p31 + p32); * enter control probs (treatment level 3, so use index 3j, j = 1, 2, 3);
odrt1 = &odrtA. ;
odrt2 = &odrtB. ;   * desired odds ratios;
run;

PROC PRINT; RUN;


PROC MODEL DATA = cprbs3;
* Treatment 1 vs Control;
(p11+ p12+ p13) - 1 = 0;
( (1/odrt1) * ((p11      )*(p32+ p33) /(p31    )) ) - (p12 + p13)  = 0;
( (1/odrt1) * ((p11 + p12)*(     p33) /(p31+p32)) ) - (      p13)  = 0;
* Treatment 2 vs Control;
(p21+ p22+ p23) - 1 = 0;
( (1/odrt2) * ((p21      )*(p32+ p33) /(p31    )) ) - (p22 + p23)  = 0;
( (1/odrt2) * ((p21 + p22)*(     p33) /(p31+p32)) ) - (      p23)  = 0;

solve p11 p12 p13
      p21 p22 p23 /  out=root3 ;

RUN; QUIT;

proc print data=root3 NOobs;
by _TYPE_ _MODE_ _ERRORS_;
var od: p1: p2: p3: ;
run;

proc transpose  data=root3 out=root3a name = probs prefix=p;
var p: ;
run;
proc print; run;

proc sort; by probs;

data prbsC; set root3a;
  x = INPUT(substr(probs,2,1),2.0);
rsp = INPUT(substr(probs,3,1),2.0);
proc print; run;


%LET alpha = 0.05;
%let  k = 3;   * three level ordinal response variable;
%let rf = 3;   * category coded x=3 is reference (control) ;

%_results; * initialize data set to store results (needed for looping through a macro);

%ordpwr(prbsC,  50,  50,  50);  * (data set name, k=3 ordinal levels with sample sizes N1, N2, N3);
%ordpwr(prbsC,  75,  75,  75);
%ordpwr(prbsC, 100, 100, 100);

proc print data=powerclgt; BY alpha;
id nA nB nC;
title 'power, sample size, odds ratios (differ from target due to rounding group sample sizes to integers)';
FORMAT power: 7.3 or: 7.2;
run;



* k = 5;

%LET odrt = 2;

PROC DATASETS nolist;
DELETE root5 root5a prbsC;
RUN; QUIT;

data cprbs;
p21 = 1/5; p22 = 1/5;  p23 = 1/5; p24 = 1/5 ; p25 = 1 - (p21 + p22 + p23 + p24); * control group probs;
run;
proc print; run;

PROC MODEL DATA = cprbs;
(p11+ p12+ p13 +p14 + p15) - 1 = 0;
( ( 1/&odrt. ) * (p11                  ) * ((p22 + p23 + p24 + p25) / (p21                  ))) - (p12 + p13 + p14 + p15) = 0;
( ( 1/&odrt. ) * (p11 + p12            ) * ((      p23 + p24 + p25) / (p21 + p22            ))) - (      p13 + p14 + p15) = 0;
( ( 1/&odrt. ) * (p11 + p12 + p13      ) * ((            p24 + p25) / (p21 + p22 + p23      ))) - (            p14 + p15) = 0;
( ( 1/&odrt. ) * (p11 + p12 + p13 + p14) * ((                  p25) / (p21 + p22 + p23 + p24))) - (                  p15) = 0;

solve p11 p12 p13 p14 p15 / out=root5; 
RUN; QUIT;

proc transpose  data=root5 out=root5a name = probs prefix=p;
var p: ;
run;
proc print; run;

proc sort; by probs;

data prbsC; set root5a;
  x = INPUT(substr(probs,2,1),2.0);
rsp = INPUT(substr(probs,3,1),2.0);
odrt = &odrt. ;

proc print data=prbsC;
by odrt;
id probs;
run;



%LET alpha = 0.05;
%let  k = 5; * five level ordinal response variable;
%let rf = 2; * category coded x=2 is reference (control) ;

%_results; * initialize data set to store results (needed for looping through a macro);

%ordpwr(prbsC, 100, 100,  0);
%ordpwr(prbsC, 125, 125,  0);
%ordpwr(prbsC, 150, 150,  0);

proc print data=powerclgt; BY alpha;
ID nA nB nC;
title 'power, sample size, odds ratios (differ from target due to rounding group sample sizes to integers)';
FORMAT power: 7.3 or: 7.2;
run;



* Slides 23-25: adjacent logit power calculation;

DATA cntr_probs;
p21 = 0.3; p22 = 0.4; p23 = 0.2 ; p24 = 1 - (p21 + p22 + p23); 
odrt = 1.5;
RUN;

* Solve for p11 p12 p13 p14 (four unknowns with four equations) ;

PROC MODEL DATA = cntr_probs;
(p11 + p12 + p13 + p14) - 1 = 0;
*p=3;  ((1/odrt) * (p11 * p22) / p21 ) - p12 = 0;
       ((1/odrt) * (p12 * p23) / p22 ) - p13 = 0;
*p=4;  ((1/odrt) * (p13 * p24) / p23 ) - p14 = 0;

SOLVE p11 p12 p13 p14 / out=root2 ;
RUN; QUIT;

proc transpose  data=root2 out=root2a name = probs prefix=p;
var p: ;
run;
proc print; run;

proc sort; by probs;

data prbsC; set root2a;
  x = INPUT(substr(probs,2,1),2.0);
rsp = INPUT(substr(probs,3,1),2.0);
odrt = &odrt. ;

proc print data=prbsC;
by odrt;
id probs;
run;


* enter treatment group sample sizes;

%LET gA = 100;
%LET gB = 100;
%LET gC = 0;

DATA _cnts;
SET prbsC ;
ARRAY cnt{3} _temporary_ (&gA. &gB. &gC. );
nn = ROUND(cnt{x}*p1,1);
RUN;
proc print; run;



PROC TABULATE DATA = _cnts noseps;
CLASS x rsp; freq nn;
table x='Treatment', (rsp='Response' all)*n*f=5.0 rsp=' '*rowpctn='row %'*f=5.1 / rts=12;
title "Exemplary Data: N1 = &gA | N2 = &gB | N3 = &gC";
run;

* save chi-square values from the Likelihood ratio and Score tests;

ods select responseprofile ;
ods output globaltests=_gbl3(where=(substr(test,1,2)='Li' or substr(test,1,2)='Sc' ))
           oddsratios= _odrtC;

proc LOGISTIC data = _cnts ;
freq nn;
class x(ref="&rf") / PARAM=ref;
model rsp = x / link=alogit PL;
title 'LOGISTIC: cumulative logit';
output out=prd(drop=rsp nn sm p) predicted=pred;
run;

proc print data=_odrtC; title "Odds Ratio"; run;

proc transpose data=_odrtC OUT=_odrtC(drop=_name_ _label_) prefix=OR_;
var oddsratioEst;
*proc print; run;

proc print data =_gbl3; title "Chisquare tests"; run;

* compute power for given sample size based on non-central chisquare ;

DATA _pwr; SET _gbl3;
alpha=&alpha. ;
nA = &gA. ;
nB = &gB. ;
nC = &gC. ;
totalN = SUM(nA, nB, nC);
c_crit = CINV(1-alpha,df);
powerC = 1-probchi(c_crit,df,ChiSq);
*proc print noobs; run;

proc transpose data=_pwr out=_powerA(drop=_name_ _label_) prefix = power_;
by alpha nA nB nC totalN;
var powerC;
id test;

data _powerA ; set _powerA ; set _odrtC;

proc print data=_powerA NOObs;
by alpha nA nB nC;
id totalN;
format power: 5.3;
title2 'LOGISTIC: power, sample size, odds ratios';
run;

PROC DATASETS NOlist;
DELETE _cnts _gbl3 _pwr _odrtC _powerA;
RUN; QUIT;
