

/*
Problem Solving: A Statistician's Guide by Chris Chatfield
A popular text on Applied Statistics, now in its 2nd edition.
Can be used for as a text for a course of practical case studies in statistics at the advanced undergraduate or graduate level.

2nd edition published by Chapman & Hall in 1995.
Now reprinted by Chapman & Hall/CRC Press. Total sales exceed 8,000.
ISBN is 1-412-60630-5
325 pages.

This book sets out to clarify the general principles involved in tackling real-life statistical problems.
It is aimed at students and practitioners who have studied some basic theory but are unsure what to do when
faced with real data, especially if the data are 'messy' or the objectives are unclear.
The book is in two parts. The first part illuminates the complex process of problem-solving.
It covers topics such as problem-formulation, report-writing and using the library as well as
looking at more methodological questions such as how best to summarize data, design an experiment,
and choose an appropriate method of analysis. The second part consists of a large number of case studies
which are problem-based and include real data. Some guidance on tackling each problem is given,
but separated from the original statement of the problem. The book ends with an extended appendix
giving a valuable summary of required statistical topics and references.

Two of the data sets used in the book are available below. The Backache in pregnancy data is also available in the StatLib Index at

http://lib.stat.cmu.edu/

    Exercise D.2 -- Backache in pregnancy data.
    Exercise B.8 -- Hips data. 

The book may be ordered from CRC Press as follows:
In America, Asia and Australasia, send an email to orders@crcpress.com or telephone 1-800-272-7737 in USA or 1-561-994-0555 from outside USA.
In Europe, Middle East and Africa, you can make enquiries by sending an email to enquiries@crcpress.com or by telephoning (44 outside UK) or (0 inside UK) 20 8875 4370. You can email your order to crcpress@itps.co.uk or telephone the orders department at (44 or 0) 1264 342932.
Or you can order online at www.crcpress.com 


These data are from "Problem-Solving" (2nd edn, 1995, Chapman and Hall, Exercise D.2) on "backache in pregnancy" is in somewhat different
format from that listed in the book. Each integer is preceded by a space.
This makes it easier to read. 

Note that the data are also now available in the Statlib archive via the WWW at  http://lib.stat.cmu.edu/

Chris Chatfield.
cc@maths.bath.ac.uk 


available at:

https://www.openml.org/search?type=data&sort=runs&id=463&status=active

*/

data bckach;
input obs severity month age; * remainder of items unknown;
sqrAge= sqrt(age);
lnAge = Log(age);
IF Severity = 0 then severity = 1;
trimester = (month > 6) + (Month > 3) + 1;
cards;
   1 1  0 26 1.52 54.5  75.0 3.35 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
   2 3  0 23 1.60 59.1  68.6 2.22 1 2 1 0 0 1 0 0 0 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0
   3 2  6 24 1.57 73.2  82.7 4.15 0 1 0 0 0 1 1 0 1 0 1 0 0 1 0 1 0 0 0 0 0 0 0 0 0
   4 1  8 22 1.52 41.4  47.3 2.81 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0
   5 1  0 27 1.60 55.5  60.0 3.75 1 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
   6 1  7 32 1.75 70.5  85.5 4.01 2 4 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 1 0
   7 1  0 24 1.73 76.4  89.1 3.41 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
   8 1  8 25 1.63 70.0  85.0 4.01 1 1 0 0 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
   9 2  6 20 1.55 52.3  59.5 3.69 1 4 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0
  10 2  8 18 1.63 83.2  90.9 3.30 0 1 1 0 0 0 0 1 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 1 0
  11 1  0 21 1.65 64.5  75.5 2.95 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  12 1  0 26 1.55 49.5  53.6 2.64 0 1 1 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  13 2  6 35 1.65 70.0  82.7 3.64 7 2 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 0 0
  14 1  8 26 1.60 52.3  64.5 4.49 1 3 0 0 1 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
  15 1  6 34 1.68 68.2  77.3 3.75 3 3 0 0 0 1 0 0 1 0 1 0 0 0 0 1 0 0 0 0 0 1 0 0 0
  16 0  0 25 1.50 47.3  55.0 2.73 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  17 1  7 42 1.52 66.8  73.2 2.44 6 4 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0
  18 2  6 26 1.65 70.0  81.4 3.01 1 3 0 0 0 1 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 1 0
  19 2  6 18 1.60 56.4  70.0 3.89 1 3 0 0 0 1 0 1 0 0 0 0 0 0 0 1 0 0 0 0 0 1 0 0 1
  20 0  1 42 1.65 53.6  63.6 2.73 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  21 2  0 28 1.63 59.1  72.3 3.75 1 3 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 1 0 0 1
  22 1  0 26 1.52 44.5  56.4 3.49 0 1 0 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0
  23 1  0 23 1.57 55.9  60.9 3.07 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  24 2  6 21 1.55 57.3  77.3 3.35 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 1
  25 2  7 32 1.52 69.5  75.5 3.64 5 3 0 0 1 0 0 0 1 0 0 1 0 1 0 1 0 0 0 0 0 0 0 0 0
  26 1  8 18 1.60 73.2  81.4 2.05 0 1 0 0 0 0 1 0 0 0 0 1 0 0 0 1 0 0 0 0 1 0 0 0 0
  27 1  0 25 1.70 52.3  59.5 2.44 1 3 1 0 0 0 0 0 0 0 0 0 0 1 0 1 0 1 0 0 1 0 0 0 0
  28 1  0 30 1.63 62.7  72.3 3.07 4 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  29 1  0 19 1.65 73.6  92.7 3.35 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  30 2  7 26 1.65 70.0  89.1 3.21 1 2 0 0 0 0 0 0 0 0 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0
  31 1  8 28 1.68 56.8  70.9 3.41 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0
  32 1  0 21 1.60 58.2  69.5 3.30 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 0 0 0 0 0 1 1 0 1
  33 0  0 29 1.57 68.2  75.0 3.35 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  34 1  8 27 1.65 50.9  66.4 3.10 1 2 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
  35 2  2 30 1.60 50.9  62.7 3.75 1 2 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0
  36 2  5 26 1.75 69.5  84.1 4.20 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0
  37 1  8 21 1.60 62.7  73.2 2.95 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1
  38 2  2 24 1.73 63.6  69.5 3.18 1 2 0 0 0 0 0 1 0 0 1 1 1 0 0 1 0 0 0 0 0 1 0 0 0
  39 2  8 28 1.50 55.5  66.4 4.35 2 4 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  40 1  8 27 1.57 55.9  62.3 3.69 0 1 0 0 1 1 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0
  41 3  6 32 1.60 47.7  66.8 3.41 5 3 1 0 1 0 0 0 0 0 1 0 0 1 0 0 0 0 1 0 0 0 0 0 1
  42 3  5 26 1.63 55.5  63.2 3.30 0 1 0 0 0 1 1 0 0 1 1 0 0 1 0 1 0 0 0 0 0 0 1 1 0
  43 2  7 37 1.63 60.9  69.5 3.41 2 2 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
  44 3  7 31 1.60 60.5  77.3 3.27 1 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  45 1  0 24 1.57 62.3  77.3 3.38 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  46 3  5 24 1.65 57.3  73.6 3.69 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 1 0 0 0 0 0 1 0 0 1
  47 1  0 23 1.52 55.5  69.5 3.35 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  48 2  3 31 1.60 47.7  55.9 1.62 0 1 1 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  49 1  8 37 1.60 76.4  89.1 3.58 1 3 0 0 0 1 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0
  50 2  6 23 1.65 95.5  95.5 2.73 1 2 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 1
  51 1  4 39 1.70 72.3  89.1 3.44 0 1 0 0 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 1 0 0
  52 2  6 32 1.70 65.9  75.0 3.66 1 4 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 0
  53 2  4 30 1.52 50.9  57.3 2.56 1 3 0 1 1 0 1 0 0 0 1 0 1 1 1 1 0 0 0 0 0 1 0 0 0
  54 2  3 24 1.57 57.3  58.6 1.08 0 1 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  55 1  0 24 1.75 69.1  77.3 3.38 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  56 2  6 29 1.55 47.7  54.5 3.81 2 3 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0
  57 1  0 24 1.75 59.1  68.6 2.98 3 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  58 2  7 27 1.70 60.0  71.4 2.95 1 2 1 0 0 1 0 0 1 0 0 1 0 1 0 0 0 0 1 1 0 0 1 0 0
  59 2  4 30 1.57 60.0  75.9 2.84 1 2 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0
  60 2  3 32 1.63 66.4  82.7 2.64 2 3 1 0 0 1 1 1 1 0 0 0 0 1 0 0 0 0 0 0 0 1 1 1 0
  61 1  0 23 1.55 44.5  48.2 2.27 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  62 1  0 18 1.60 63.6  75.0 3.47 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  63 2  9 28 1.55 47.7  58.2 2.56 1 2 0 0 0 1 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 0 0 0
  64 1  0 24 1.50 45.9  55.0 3.10 1 4 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0
  65 1  5 22 1.68 53.2  64.5 3.07 0 1 0 0 0 0 0 0 1 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 1
  66 2  5 29 1.57 60.5  74.1 3.27 1 3 0 0 0 1 0 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0
  67 3  2 30 1.65 89.5  97.7 3.81 1 3 0 1 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0
  68 2  4 22 1.70 61.8  75.5 3.21 0 1 1 1 0 0 0 0 1 0 1 1 1 1 0 0 0 0 0 0 0 1 0 0 0
  69 2  5 31 1.63 66.4  82.3 2.27 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0
  70 1  0 29 1.57 60.5  64.1 3.30 3 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  71 1  0 28 1.65 60.5  73.2 3.75 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  72 3  6 32 1.60 47.7  50.5 1.90 3 3 0 0 1 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 1 0 0
  73 1  7 21 1.55 67.3  80.0 3.27 0 1 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  74 2  5 24 1.50 50.0  63.6 2.76 0 1 0 0 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  75 2  5 26 1.65 55.5  67.3 4.15 2 4 0 0 0 1 0 1 0 0 1 0 1 0 1 1 0 0 0 0 0 1 0 0 0
  76 1  0 26 1.73 57.3  65.5 3.07 1 2 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0
  77 2  7 26 1.60 65.0  80.5 3.95 0 1 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0
  78 3  0 28 1.65 57.3  82.7 3.89 0 1 0 0 0 1 0 0 1 0 1 1 0 0 1 1 0 0 0 0 0 1 1 0 0
  79 2  0 36 1.73 75.9  87.3 3.64 1 3 0 0 0 1 0 0 1 0 1 1 1 1 1 1 0 0 0 0 0 0 0 0 1
  80 2  7 29 1.55 75.5  78.6 2.61 0 1 0 0 0 0 0 0 1 0 1 0 1 0 0 0 0 0 0 0 1 0 0 0 0
  81 1  7 23 1.65 47.7  51.8 2.84 1 3 0 0 0 1 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 1 0 0 1
  82 3  8 19 1.70 57.3  74.5 3.69 2 2 0 1 1 1 0 1 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 1
  83 3  7 30 1.73 63.6  80.5 3.61 0 4 1 0 0 1 0 0 1 0 0 0 1 0 0 0 0 0 0 0 0 1 0 0 0
  84 2  6 24 1.60 50.0  59.1 3.52 1 2 0 0 1 1 0 1 0 0 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0
  85 1  0 24 1.70 60.0  65.0 3.18 0 1 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  86 1  0 30 1.55 47.7  59.1 3.15 1 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  87 2  5 25 1.65 50.5  60.9 3.35 1 2 0 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0
  88 3  7 23 1.55 62.7  85.5 4.18 0 1 0 0 0 1 0 0 0 0 0 1 1 1 1 1 0 0 0 0 0 1 0 0 1
  89 3  3 33 1.63 63.6  70.9 2.93 1 3 1 0 0 1 0 0 1 0 1 0 0 0 0 1 0 0 0 0 0 1 0 0 0
  90 1  0 31 1.52 52.3  53.2 2.39 2 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  91 2  7 21 1.50 63.6  63.6 2.98 2 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  92 1  0 27 1.75 68.2  82.7 5.97 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  93 1  5 25 1.60 68.2  76.4 3.18 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
  94 3  2 34 1.63 66.8  80.5 4.15 3 2 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1
  95 2  6 26 1.70 65.9  68.2 3.35 1 4 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  96 0  0 20 1.57 60.5  69.5 3.24 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
  97 2  0 28 1.68 89.1  94.5 2.59 0 1 0 0 0 1 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0
  98 2  0 26 1.70 80.5  89.1 1.42 0 0 1 0 0 1 0 0 1 0 1 1 1 1 1 1 0 0 0 0 0 1 0 0 1
  99 2  6 22 1.60 63.6  82.7 3.89 2 3 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0
 100 2  4 26 1.50 43.6  53.6 3.81 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1
 101 1  8 21 1.55 54.5  67.3 3.72 0 1 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
 102 1  7 18 1.60 62.7  71.4 2.44 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 103 2  6 22 1.52 54.1  65.0 2.78 0 1 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0
 104 0  0 20 1.63 53.6  73.2 2.78 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 105 1  0 25 1.65 61.8  66.8 3.18 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 106 2  4 23 1.57 76.4  87.3 2.78 1 1 0 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 0 0
 107 1  5 22 1.60 74.5  82.7 2.90 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0
 108 2  6 22 1.68 47.7  53.6 3.01 3 3 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 0 0 0
 109 1  8 32 1.63 52.3  56.8 2.50 0 1 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 110 2  6 26 1.57 53.6  65.0 2.87 1 2 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0
 111 1  0 25 1.63 58.6  62.3 2.44 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 112 0  1 19 1.57 51.8  71.8 3.35 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 113 1  0 21 1.60 76.4  78.2 3.07 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 114 1  0 23 1.60 56.4  71.4 2.50 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 115 2  7 20 1.60 54.1  68.2 3.58 0 1 0 0 0 1 0 0 0 1 0 0 0 1 0 1 0 0 0 0 0 0 1 0 1
 116 1  4 19 1.65 57.3  70.0 2.61 1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 117 2  8 30 1.50 53.2  66.4 3.98 1 3 0 0 1 0 0 1 0 0 0 1 0 1 0 0 0 0 0 0 0 1 0 0 0
 118 1  0 26 1.60 57.3  65.9 3.89 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0
 119 1  0 24 1.57 60.5  74.5 3.24 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 120 1  6 28 1.60 46.8  60.5 2.98 1 3 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1
 121 0  0 16 1.63 60.5  65.9 3.18 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 122 1  0 29 1.63 54.5  67.3 3.58 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 123 3  6 25 1.57 59.1  69.5 3.89 1 2 0 0 0 0 0 0 1 0 1 0 1 0 0 0 0 0 0 0 1 1 0 0 1
 124 2  3 17 1.52 48.2  61.8 2.78 0 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0 0 1 1 1 0 0 0 0 0
 125 1  7 23 1.65 77.3  83.2 3.58 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
 126 1  0 26 1.63 72.7  80.0 2.95 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 127 1  0 20 1.63 58.6  70.0 2.84 1 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 128 2  2 25 1.68 54.5  71.8 3.72 0 1 0 0 0 1 0 0 1 0 0 0 1 1 0 1 0 0 0 0 0 0 0 0 0
 129 1  3 24 1.63 61.8  73.6 2.84 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 0
 130 3  3 35 1.63 69.5  72.3 3.52 2 2 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0
 131 0  0 28 1.70 78.2  98.6 2.84 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 132 3  4 25 1.63 79.5  90.5 3.15 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0
 133 1  6 22 1.63 60.5  77.7 2.39 0 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0
 134 1  7 42 1.50 44.5  48.6 2.27 5 2 1 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 0 0 1
 135 1  8 21 1.60 60.5  73.2 3.27 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
 136 2  4 20 1.52 60.5  75.0 3.64 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0
 137 1  0 24 1.63 56.4  70.0 3.07 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 138 1  5 33 1.65 40.0  55.0 3.47 0 1 1 0 0 0 0 0 0 0 0 1 0 0 1 0 0 0 0 1 0 1 0 0 0
 139 1  6 33 1.65 63.6  82.7 3.86 0 1 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0
 140 3  3 29 1.63 58.2  65.5 2.84 1 3 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 141 2  8 27 1.65 57.3  69.5 3.64 0 1 0 0 0 1 0 0 1 0 1 1 0 1 0 0 0 0 0 0 0 1 0 0 0
 142 3  3 20 1.52 44.5  51.4 1.93 1 3 0 0 0 0 0 0 0 0 1 0 0 1 0 1 0 1 0 0 1 1 1 1 1
 143 2  6 18 1.63 49.1  56.8 3.24 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 1 0 1 0 0
 144 2  7 26 1.57 52.7  65.9 3.49 0 1 0 0 0 1 0 0 1 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0
 145 1  7 21 1.55 52.3  65.0 3.47 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0
 146 2  4 21 1.52 50.9  68.2 3.64 0 1 0 0 0 0 0 0 1 0 0 0 0 1 0 1 0 0 0 0 0 1 0 0 0
 147 1  5 21 1.68 66.8  87.3 2.90 0 1 0 0 0 0 0 1 1 0 0 1 1 1 0 1 0 0 0 0 0 0 0 0 0
 148 1  0 26 1.65 50.9  70.0 3.52 0 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 149 1  8 21 1.55 53.2  56.4 2.44 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1
 150 2  7 22 1.47 44.5  58.2 2.87 0 1 0 0 0 1 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 0 0 0 0
 151 3  7 39 1.50 50.9  72.7 3.04 4 2 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 1
 152 2  6 27 1.63 60.5  71.4 3.21 0 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 0 1 1 0 0 0
 153 1  0 24 1.57 60.0  72.7 3.35 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 154 1  4 24 1.63 64.5  75.0 2.87 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
 155 1  7 19 1.55 52.7  57.7 2.61 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0
 156 1  0 22 1.60 67.3  73.6 2.05 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 157 3  8 27 1.55 60.5  73.2 3.98 0 1 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0
 158 3  2 35 1.73 72.3  89.1 6.28 3 3 1 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 0 0
 159 0  0 24 1.65 83.6  86.8 3.64 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 160 1  0 35 1.55 52.3  59.1 3.64 0 1 0 0 0 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0
 161 1  0 21 1.52 59.1  67.3 2.95 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 162 3  7 21 1.68 54.1  74.5 3.72 1 2 0 0 0 0 0 0 1 0 1 1 1 1 0 1 0 0 0 0 0 1 0 0 1
 163 3  9 38 1.52 43.6  60.9 3.24 1 4 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 164 1  0 32 1.73 54.5  62.7 3.41 1 3 0 0 0 1 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 1 0 0 0
 165 3  8 15 1.55 48.2  56.4 2.70 0 1 1 0 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 166 2  6 23 1.57 60.5 100.0 3.58 0 1 0 0 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 167 2  7 19 1.50 49.5  63.6 3.35 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 1
 168 2  8 25 1.60 59.5  72.3 2.73 1 3 0 0 0 0 0 1 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0
 169 2  5 22 1.50 53.6  63.2 3.35 0 1 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
 170 0  0 19 1.55 57.3  65.0 3.07 1 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 171 1  0 23 1.68 57.3  61.4 3.58 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 172 3  0 36 1.63 54.1  60.0 2.84 0 1 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 0 1 0
 173 0  0 21 1.55 50.9  63.6 3.01 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 174 0  0 30 1.52 38.2  48.2 2.56 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 175 0  0 42 1.70 55.0  65.5 3.27 4 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 176 1  0 34 1.63 50.9  60.5 2.93 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
 177 3  3 26 1.63 66.8  84.1 3.10 1 3 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 1 0 0
 178 1  7 18 1.50 54.1  60.5 3.52 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
 179 3  6 39 1.52 82.7  84.1 3.35 1 2 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 180 1  0 25 1.52 52.3  66.8 3.24 1 2 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0
;


proc freq data=bckach;
table severity;
run;

proc print data=bckach(obs=5);
run;

